# frozen_string_literal: true

require 'test_helper'

describe BridgeAPI::Client::LiveCourseSession do
  before do
    @client = BridgeAPI::Client.new(prefix: 'http://test.bridge.com', token: 'test_token')
  end

  it 'should list the live course sessions' do
    response = @client.get_live_course_sessions(1)
    expect(response.status).to eq(201)
  end

  it 'should list the live course session' do
    response = @client.get_live_course_session(1, 5)
    expect(response.status).to eq(201)
  end

  it 'should create a live course session in bridge' do
    params = {
      sessions: [{
        start_at: '2018-08-07T15:00:00.918Z',
        end_at: '2018-08-07T16:00:00.918Z',
        timezone: 'America/Denver'
      }]
    }
    response = @client.create_live_course_session(1, params)
    expect(response.status).to eq(201)
  end

  it 'should delete a live course session in bridge' do
    response = @client.delete_live_course_session(1, 5)
    expect(response.status).to eq(204)
  end

  it 'should update the existing live course session' do
    params = {
      sessions: [{
        seats: 5
      }]
    }
    response = @client.update_live_course_session(1, 5, params)
    expect(response.status).to eq(200)
  end

  it 'should update web_conference' do
    params = {
      web_conference: {
        provider: 'Bluejeans'
      }
    }
    response = @client.update_web_conference(1, 5, params)
    expect(response.status).to eq(200)
  end

  it 'should publish a live course session' do
    response = @client.publish_live_course_session(1, 5)
    expect(response.status).to eq(200)
  end

  it 'should get default web_conference config' do
    response = @client.get_default_web_conference(default_session: 1)
    expect(response.status).to eq(200)
  end
end
